@@ -26,7 +26,7 @@ class TestSegmentation(unittest.TestCase):
 
     def test_gbp(self):
         model = gcam.inject(self.model, output_dir=os.path.join(self.current_path, 'results/unet_seg/gbp'), backend='gbp',
-                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric="wioa", label=lambda x: 0.5 < x, channels=1)
+                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric="wioa")
         model.eval()
         data_loader = DataLoader(self.dataset, batch_size=1, shuffle=False)
 
@@ -44,7 +44,7 @@ class TestSegmentation(unittest.TestCase):
         layer = 'full'
         metric = 'wioa'
         model = gcam.inject(self.model, output_dir=os.path.join(self.current_path, 'results/unet_seg/gcam'), backend='gcam', layer=layer,
-                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric, label=lambda x: 0.5 < x, channels=1)
+                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric)
         model.eval()
         data_loader = DataLoader(self.dataset, batch_size=1, shuffle=False)
         model.test_run(next(iter(data_loader))["img"])
@@ -63,7 +63,7 @@ class TestSegmentation(unittest.TestCase):
         layer = 'full'
         metric = 'wioa'
         model = gcam.inject(self.model, output_dir=os.path.join(self.current_path, 'results/unet_seg/gcam_overlay'), backend='gcam', layer=layer,
-                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric, label=lambda x: 0.5 < x, channels=1)
+                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric)
         model.eval()
         data_loader = DataLoader(self.dataset, batch_size=1, shuffle=False)
         model.test_run(next(iter(data_loader))["img"])
@@ -82,7 +82,7 @@ class TestSegmentation(unittest.TestCase):
         layer = 'full'
         metric = 'wioa'
         model = gcam.inject(self.model, output_dir=os.path.join(self.current_path, 'results/unet_seg/ggcam'), backend='ggcam', layer=layer,
-                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric, label=lambda x: 0.5 < x, channels=1)
+                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric)
         model.eval()
         data_loader = DataLoader(self.dataset, batch_size=1, shuffle=False)
         model.test_run(next(iter(data_loader))["img"])
@@ -101,7 +101,7 @@ class TestSegmentation(unittest.TestCase):
         layer = 'full'
         metric = 'wioa'
         model = gcam.inject(self.model, output_dir=os.path.join(self.current_path, 'results/unet_seg/gcampp'), backend='gcampp', layer=layer,
-                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric, label=lambda x: 0.5 < x, channels=1)
+                            evaluate=True, save_scores=False, save_maps=True, save_pickle=False, metric=metric, label=lambda x: 0.5 < x)
         model.eval()
         data_loader = DataLoader(self.dataset, batch_size=1, shuffle=False)
         model.test_run(next(iter(data_loader))["img"])
